@@ -27,7 +27,7 @@ config = {
 					#"(^([^_]+)_[a-z]+[,\\.$]?)",  
 					"(^[^_]+)",   # first lex
 					#"(_[a-z]+_[VERB|NOUN|ADJ|ADV]+)$", # lex_tag_lem_pos , _contact_VERB (VERB|NOUN|ADJ|ADV)
-					"(_[a-zA-Z\\-\\.\\'\\$0-9]+)$",
+					#"(_[a-zA-Z\\-\\.\\'\\$0-9]+)$",  # remove _NP5,  _NP5 => _NP 
 					"(_[a-zA-Z,\\-\\.\\'\\$]+)",  # _^ _ADJ _, _NOUN _VERB
 					#"(_[^\\w]+)_",
 					#"([^\\w])_"
@@ -439,7 +439,7 @@ def init(idxname):
 def testana(index:str='test'):
 	arr = requests.post(f"http://{requests.eshost}/{index}/_analyze", json={
   "analyzer": "postag_ana",
-  "text": "booked_,_VBD_book_VERB"
+  "text": "booked_,_VBD_book_VERB_NP5"
 }).json() 
 	for t in arr['tokens']:
 		print (t) 
