@@ -68,6 +68,18 @@ def hset_if_greater(r, key, eid, ver ):
 	except Exception as e:
 		print("ex:", e, eid)
 
+# nltk
+def traverse(t, label='NP', f = lambda t:  print(t.pos()) ):
+  try:
+      t.label()
+  except AttributeError:
+      return
+  else:
+      if t.label() == label: f(t)  # or do something else
+      else:
+          for child in t: 
+              traverse(child, label, f)
+
 if __name__ == '__main__': 
 	pass 
 	#logger = getlog()
